@@ -410,7 +410,7 @@ tag <- gsub("path:hsa", "", ptag)
 ###################################################
 library(KEGGgraph)
 dest <- tempfile()
-retrieveKGML(tag, "hsa", dest, "internal")
+retrieveKGML(tag, "hsa", dest, method="auto")
 
 
 ###################################################
